Class: Wsdl::WsdlParser

Inherits:
Object
  • Object
show all
Defined in:
lib/wsdl/wsdl_parser.rb

Class Method Summary collapse

Class Method Details

.parse(service) ⇒ Object

Parse the service wsdl to a Wsdl object Params :

service

the url of the service



12
13
14
15
16
17
18
19
20
21
22
23
# File 'lib/wsdl/wsdl_parser.rb', line 12

def self.parse(service)
  @service = service
  wsdl_xml = get_serivce_data('wsdl')
  doc = XmlSimple.xml_in(wsdl_xml)

  res = Wsdl.new
  res.actions = get_soap_actions(doc)
  res.location_address = get_location_address(doc)
  res.target_namespace = doc['targetNamespace']

  res
end

.target_namespaceObject

Return the target namespace of the last wsdl parser. TODO: Remove this method and user tel Wsdl it self to get the target namespace



27
28
29
# File 'lib/wsdl/wsdl_parser.rb', line 27

def self.target_namespace
  @@target_namespace
end